@@ -21,6 +21,9 @@ library(taxonomizr)
 ## ----eval=FALSE---------------------------------------------------------------
 #  prepareDatabase('accessionTaxa.sql')
 
+## ----eval=FALSE---------------------------------------------------------------
+#  prepareDatabase(getAccessions=FALSE)
+
 ## ----eval=FALSE---------------------------------------------------------------
 #  blastResults<-read.table('XXXX.blast',header=FALSE,stringsAsFactors=FALSE)
 #  #grab the 4th |-separated field from the reference name in the second column
@@ -56,6 +59,13 @@ library(taxonomizr)
 #  groupings<-c('read1','read2','read1','read2')
 #  condenseTaxa(taxa,groupings)
 
+## ----eval=FALSE---------------------------------------------------------------
+#  getRawTaxonomy(c(9606,9913),'accessionTaxa.sql')
+
+## ----eval=FALSE---------------------------------------------------------------
+#  raw<-getRawTaxonomy(c(9606,9913),'accessionTaxa.sql')
+#  normalizeTaxa(raw)
+
 ## ----eval=FALSE---------------------------------------------------------------
 #  read.accession2taxid(list.files('.','accession2taxid.gz$'),'accessionTaxa.sql',indexTaxa=TRUE,overwrite=TRUE)
 
@@ -69,6 +79,17 @@ taxa<-matrix(c('Eukaryota','Chordata','Mammalia','Primates','Hominidae','Homo','
 taxa
 makeNewick(taxa)
 
+## -----------------------------------------------------------------------------
+makeNewick(taxa,quote="'")
+
+## -----------------------------------------------------------------------------
+taxa[3,3:6]<-NA
+print(taxa)
+makeNewick(taxa)
+
+## -----------------------------------------------------------------------------
+makeNewick(taxa,excludeTerminalNAs=TRUE)
+
 ## ----eval=FALSE---------------------------------------------------------------
 #  getNamesAndNodes()
 
